=== modified file 'NEWS'
--- NEWS	2007-09-18 01:29:59 +0000
+++ NEWS	2007-09-18 18:55:00 +0000
@@ -47,6 +47,9 @@
 
    * Fix commit ordering in corner case (Aaron Bentley, #94975)
 
+   * Fix log against smart server branches that don't support tags.
+     (James Westby, #140615)
+
   API BREAKS:
 
    * The ``VersionedFile`` interface now allows content checks to be bypassed

=== modified file 'bzrlib/tag.py'
--- bzrlib/tag.py	2007-09-11 03:07:14 +0000
+++ bzrlib/tag.py	2007-09-18 18:55:00 +0000
@@ -66,6 +66,10 @@
         # we never have anything to copy
         pass
 
+    def get_reverse_tag_dict(self):
+        # There aren't any tags, so the reverse mapping is empty.
+        return {}
+
 
 class BasicTags(_Tags):
     """Tag storage in an unversioned branch control file.

=== modified file 'bzrlib/tests/test_tag.py'
--- bzrlib/tests/test_tag.py	2007-09-11 03:17:05 +0000
+++ bzrlib/tests/test_tag.py	2007-09-18 18:55:00 +0000
@@ -24,6 +24,7 @@
 from bzrlib.tag import (
     BasicTags,
     _merge_tags_if_possible,
+    DisabledTags,
     )
 from bzrlib.tests import (
     KnownFailure,
@@ -151,3 +152,19 @@
             "https://bugs.launchpad.net/bzr/+bug/138802")
         self.assertRaises(errors.NoSuchTag,
             child.tags.lookup_tag, 'foo')
+
+class DisabledTagsTests(TestCaseWithTransport):
+
+    def setUp(self):
+        super(DisabledTagsTests, self).setUp()
+        branch = self.make_branch('.')
+        self.tags = DisabledTags(branch)
+
+    def test_supports_tags(self):
+        self.assertEqual(self.tags.supports_tags(), False)
+
+    def test_set_tag(self):
+        self.assertRaises(errors.TagsNotSupported, self.tags.set_tag)
+
+    def test_get_reverse_tag_dict(self):
+        self.assertEqual(self.tags.get_reverse_tag_dict(), {})

